==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/single_window/translations/single_window_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>Ventana Única</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Posición de lista</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Cambiar la posición de la lista en el modo de Ventana Única</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Accesos rápidos</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a la pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a la siguiente pestaña</translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Mostrar/Ocultar la lista</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Cambiar el enfoque entre la lista y las pestañas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/single_window/translations/single_window_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>Ventana Única</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Posición de lista</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Cambiar la posición de la lista en el modo de Ventana Única</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Accesos rápidos</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a la pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a la siguiente pestaña</translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Mostrar/Ocultar la lista</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Cambiar el enfoque entre la lista y las pestañas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
</context>
</TS>
